@@ -3,6 +3,9 @@ from pydantic import BaseModel, Field
 
 class Config(BaseModel):
     github_token: Optional[str] = None
-    ai_model_name: str = "gpt-4o-mini"
     max_context_length: int = Field(20)
     ai_reply_image: bool = False
+    ai_model_name: str = "gpt-4o-mini"
+    ai_temperature: float = Field(1.0)
+    ai_max_tokens: int = Field(1024)
+    ai_top_p: float = Field(1.0)
\ No newline at end of file
